@@ -1,4 +1,5 @@
-/* -copyright-
+/* 
+ -copyright-
 #-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
@@ -23,7 +24,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include "csvpos.h"
-#include "safe_malloc.h"
 // given s like "9,2,0" fill k with 9,2,0, set n to 3.
 // all values positive, if negative 0 is inserted
 // k is allocated in csvpos, free it with free(3)
