@@ -1,4 +1,5 @@
-/* -copyright-
+/* 
+ -copyright-
 #-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
@@ -111,6 +112,7 @@
    DOIT_I(Outline              ,0          ,0          ) \
    DOIT_I(TreeFill             ,30         ,30         ) \
    DOIT_I(TreeScale            ,100        ,100        ) \
+   DOIT_I(UseColor2            ,0          ,0          ) \
    DOIT_I(VintageFlakes        ,0          ,1          ) /* internal flag */\
    DOIT_I(WhirlFactor          ,100        ,100        ) \
    DOIT_I(WindTimer            ,30         ,30         ) \
@@ -118,6 +120,7 @@
    DOIT_I(IgnoreBottom         ,0          ,0          ) \
    \
    DOIT_S(SnowColor            ,"#fffafa"  ,"#fffafa"  ) /* "snow" */       \
+   DOIT_S(SnowColor2           ,"#87ceff"  ,"#87ceff"  ) /* "skyblue1" */       \
    DOIT_S(TreeColor            ,"#7fff00"  ,"#7fff00"  ) /* "chartreuse" */ \
    DOIT_S(TreeType             ,"1,2,3,4,5,6,7," ,"0,"        ) \
    \
