@@ -1,4 +1,5 @@
-/* -copyright-
+/* 
+ -copyright-
 #-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
@@ -65,4 +66,4 @@ extern FLAGS VintageFlags;
 extern int  HandleFlags(int argc, char*argv[]);
 extern void InitFlags(void);
 extern void SetDefaultFlags(void);
-extern void WriteFlags(void);
+extern void WriteFlags(int output_locations);
