@@ -1,4 +1,5 @@
-/* -copyright-
+/* 
+ -copyright-
 #-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
@@ -51,6 +52,7 @@
 #include <X11/extensions/Xinerama.h>
 #include <ctype.h>
 #include <gtk/gtk.h>
+#include <gdk/gdkx.h>
 #include <cairo-xlib.h>
 #include <gsl/gsl_version.h>
 #include <stdlib.h>
@@ -89,7 +91,6 @@
 #include "treesnow.h"
 #include "loadmeasure.h"
 #include "selfrep.h"
-#include "safe_malloc.h"
 #include "xdo.h"
 
 #include "vroot.h"
@@ -157,6 +158,7 @@ static void   mybindtestdomain(void);
 
 // callbacks
 static int do_displaychanged(void *);
+static int do_write_flags(void *);
 static int do_draw_all(gpointer widget);
 static int do_event(void *);
 static int do_show_range_etc(void *);
@@ -261,6 +263,7 @@ int main_c(int argc, char *argv[])
    signal(SIGINT,  SigHandler);
    signal(SIGTERM, SigHandler);
    signal(SIGHUP,  SigHandler);
+   signal(SIGUSR1, SigHandler);
    P("srand %d\n",(int)(fmod(wallcl()*1.0e6,1.0e8)));
    srand48((int)(fmod(wallcl()*1.0e6,1.0e8)));
 
@@ -272,45 +275,48 @@ int main_c(int argc, char *argv[])
    aurora_sem_init();
    birds_sem_init();
 
-   global.counter            = 0;
-   global.cpufactor          = 1.0;
-   global.WindowScale        = 1.0;
+   global.counter             = 0;
+   global.cpufactor           = 1.0;
+   global.WindowScale         = 1.0;
 
-   global.MaxSnowFlakeHeight = 0;
-   global.MaxSnowFlakeWidth  = 0;
-   global.FlakeCount         = 0;  /* # active flakes */
-   global.FluffCount         = 0;
+   global.MaxSnowFlakeHeight  = 0;
+   global.MaxSnowFlakeWidth   = 0;
+   global.FlakeCount          = 0;  /* # active flakes */
+   global.FluffCount          = 0;
 
-   global.SnowWin            = 0;
-   global.WindowOffsetX      = 0;
-   global.WindowOffsetY      = 0;
-   global.DesktopSession     = NULL;
-   global.CWorkSpace         = 0;
-   global.ChosenWorkSpace    = 0;
-   global.NVisWorkSpaces     = 1;
-   global.VisWorkSpaces[0]   = 0;
-   global.WindowsChanged     = 0;
-   global.ForceRestart       = 0;
+   global.SnowWin             = 0;
+   global.WindowOffsetX       = 0;
+   global.WindowOffsetY       = 0;
+   global.DesktopSession      = NULL;
+   global.CWorkSpace          = 0;
+   global.ChosenWorkSpace     = 0;
+   global.NVisWorkSpaces      = 1;
+   global.VisWorkSpaces[0]    = 0;
+   global.WindowsChanged      = 0;
+   global.ForceRestart        = 0;
 
-   global.FsnowFirst         = NULL;
-   global.MaxScrSnowDepth    = 0;
-   global.RemoveFluff        = 0;
+   global.FsnowFirst          = NULL;
+   global.MaxScrSnowDepth     = 0;
+   global.RemoveFluff         = 0;
 
-   global.SnowOnTrees        = NULL;
-   global.OnTrees            = 0;
+   global.SnowOnTrees         = NULL;
+   global.OnTrees             = 0;
 
-   global.moonX              = 1000;
-   global.moonY              = 80;
+   global.moonX               = 1000;
+   global.moonY               = 80;
 
-   global.Wind               = 0;
-   global.Direction          = 0;
-   global.WindMax            = 500.0;
-   global.NewWind            = 100.0;
+   global.Wind                = 0;
+   global.Direction           = 0;
+   global.WindMax             = 500.0;
+   global.NewWind             = 100.0;
 
-   global.HaltedByInterrupt  = 0;
-   global.Message[0]         = 0;
+   global.HaltedByInterrupt   = 0;
+   global.Message[0]          = 0;
 
-   global.SantaPlowRegion    = 0;
+   global.SantaPlowRegion     = 0;
+
+   global.DoCapella           = DOCAPELLA;
+   global.time_to_write_flags = TRUE;
 
    int i;
 
@@ -353,23 +359,23 @@ int main_c(int argc, char *argv[])
    int rc = HandleFlags(argc, argv);
 
    handle_language(0); // the langues used is from flags or .xsnowrc
-   //                     this changes env LANGUAGE accordingly
-   //                     so that the desired translation is in effect
+		       //                     this changes env LANGUAGE accordingly
+		       //                     so that the desired translation is in effect
 
    mybindtestdomain();
    switch(rc)
    {
       case -1:   // wrong flag
-	 //PrintVersion();
+		 //PrintVersion();
 	 Thanks();
 	 return 1;
 	 break;
       case 1:    // manpage or help
-	 //         Ok, this cannot happen, is already caught above
+		 //         Ok, this cannot happen, is already caught above
 	 return 0;
 	 break;
       default:  // ditto
-	 //PrintVersion();
+		//PrintVersion();
 	 break;
    }
    PrintVersion();
@@ -422,8 +428,6 @@ int main_c(int argc, char *argv[])
       global.IsWayland = 0;
 
    gtk_init(&argc, &argv);
-   if (!Flags.NoConfig)
-      WriteFlags();
 
    if (Flags.BelowAllForce)
       Flags.BelowAll = 0;
@@ -466,9 +470,10 @@ int main_c(int argc, char *argv[])
 	 Flags.TreeColor = strdup(DefaultFlags.TreeColor); 
       if (!ValidColor(Flags.SnowColor))
 	 Flags.SnowColor = strdup(DefaultFlags.SnowColor); 
+      if (!ValidColor(Flags.SnowColor2))
+	 Flags.SnowColor2 = strdup(DefaultFlags.SnowColor2); 
       if (!ValidColor(Flags.BirdsColor))
 	 Flags.BirdsColor = strdup(DefaultFlags.BirdsColor); 
-      WriteFlags();
    }
 
 
@@ -569,6 +574,7 @@ int main_c(int argc, char *argv[])
    add_to_mainloop(PRIORITY_DEFAULT, time_displaychanged,     do_displaychanged     );
    add_to_mainloop(PRIORITY_DEFAULT, time_event,              do_event              );
    add_to_mainloop(PRIORITY_DEFAULT, time_testing,            do_testing            );
+   add_to_mainloop(PRIORITY_DEFAULT, time_writeflags,         do_write_flags        );
    add_to_mainloop(PRIORITY_DEFAULT, time_display_dimensions, do_display_dimensions );
    add_to_mainloop(PRIORITY_HIGH,    time_ui_check,           do_ui_check           );
    add_to_mainloop(PRIORITY_DEFAULT, time_show_range_etc,     do_show_range_etc     );
@@ -582,6 +588,10 @@ int main_c(int argc, char *argv[])
 
    DoAllWorkspaces(); // to set global.ChosenWorkSpace
 
+   if (!Flags.NoConfig)
+      global.time_to_write_flags = TRUE;
+      //WriteFlags(1);
+
    P("Entering main loop\n");
    // main loop
    gtk_main();
@@ -740,7 +750,7 @@ int StartWindow()
 	    NULL,                // gdk_window
 	    &xwin,               // x11_window
 	    &wantx,              // make_trans_window tries to place the window here,
-	    //                      but, depending on window manager that does not always succeed
+				 //                      but, depending on window manager that does not always succeed
 	    &wanty
 	    );
       if (rc)
@@ -779,7 +789,7 @@ int StartWindow()
 	 // Note that the name is still case-insensitive
 	 if (!strncmp(global.DesktopSession,"LXDE",4) && 
 	       (xwin = largest_window_with_name(global.xdo,"^pcmanfm$"))
-	       )
+	    )
 	 {
 	    printf(_("LXDE session found, using window 'pcmanfm'.\n"));
 	    P("lxdefound: %d %#lx\n",lxdefound,*xwin);
@@ -993,7 +1003,11 @@ int do_ui_check(void *d)
    UIDO (Transparency        ,                                    );
    UIDO (Scale               ,                                    );
    UIDO (OffsetS             , DisplayDimensions();               );
-   UIDO (OffsetY             , UpdateFallenSnowRegionsWithLock(); );
+   UIDO (OffsetY             , 
+	 int x = global.DoCapella;
+	 global.DoCapella=0; 
+	 UpdateFallenSnowRegionsWithLock(); 
+	 global.DoCapella = x;                                    );
    UIDO (NoFluffy            , ClearScreen();                     );
    UIDO (AllWorkspaces       , DoAllWorkspaces();                 );
    UIDO (BelowAll            , set_below_above();                 );
@@ -1002,7 +1016,8 @@ int do_ui_check(void *d)
 
    if (Flags.Changes > 0)
    {
-      WriteFlags();
+      //WriteFlags(1);
+      global.time_to_write_flags = TRUE;
       set_buttons();
       P("-----------Changes: %d\n",Flags.Changes);
    }
@@ -1011,6 +1026,27 @@ int do_ui_check(void *d)
    (void)d;
 }
 
+int do_write_flags(void *d)
+{
+   const int mc = 0;
+   // if one should wait a little longer before calling WriteFlags()
+   // one could set mc to 1, 2, ...
+   static int c = mc;
+   if (global.time_to_write_flags)
+   {
+      P("c: %d\n",c);
+      if (c > 0)
+      {
+	 c--;
+	 return TRUE;
+      }
+      WriteFlags(1);
+      global.time_to_write_flags = FALSE;
+      c = mc;
+   }
+   return TRUE;
+   (void)d;
+}
 
 int do_displaychanged(void *d)
 {
@@ -1154,31 +1190,18 @@ int do_testing(void *d)
    (void)d;
    if (Flags.Done)
       return FALSE;
-   return TRUE;
-   int xret,yret;
-   unsigned int wret,hret;
-   xdo_get_window_location(global.xdo, global.SnowWin,&xret,&yret,NULL);
-   xdo_get_window_size(global.xdo, global.SnowWin, &wret, &hret);
-   P("%d wxh %d %d %d %d    %d %d %d %d \n",global.counter++,global.SnowWinX,global.SnowWinY,global.SnowWinWidth,global.SnowWinHeight,xret,yret,wret,hret);
-   P("WorkspaceActive, chosen: %d %ld\n",WorkspaceActive(),global.ChosenWorkSpace);
-   P("vis:");
-   int i;
-   for (i=0; i<global.NVisWorkSpaces; i++)
-      printf(" %ld",global.VisWorkSpaces[i]);
-   printf("\n");
-   printf("offsets: %d %d\n",global.WindowOffsetX,global.WindowOffsetY);
-   global.counter++;
-
-   for (i=0; i<global.NVisWorkSpaces; i++)
-      printf("%d: visible: %d %ld\n",global.counter,i,global.VisWorkSpaces[i]);
-
-   P("current workspace: %ld\n",global.CWorkSpace);
 
    return TRUE;
 }
 
 void SigHandler(int signum)
 {
+   if (signum == SIGUSR1)
+   {
+      I("Caught SIGUSR1\n");
+      global.time_to_write_flags = TRUE;
+      return;
+   }
    global.HaltedByInterrupt = signum;
    Flags.Done        = 1;
 }
