@@ -1,5 +1,5 @@
 #!/bin/sh
-# -copyright-
+###### -copyright-
 #-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
@@ -19,14 +19,16 @@
 #-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #-# 
 
-XSNOW=xsnow
+XSNOW=/usr/games/xsnow
 if [ -x ./xsnow ]; then
    XSNOW=./xsnow
 fi
 # test if 'xsnow -h' more or less works:
 $XSNOW -h | grep -q -i xsnow 
-if [ $? -ne 0 ] ; then
-   echo "Error in executing: $XSNOW -h"
+if [ $? -eq 0 ] ; then
+   echo "PASSED: running $XSNOW -h"
+else
+   echo "FAILED: error in executing: $XSNOW -h"
    exit 1
 fi
 # test if all default values are substituted:
@@ -36,5 +38,3 @@ if [ $? -eq 0 ] ; then
    $XSNOW -h | grep DEFAULT_
    exit 1
 fi
-
-
