@@ -1,4 +1,5 @@
-/* -copyright-
+/* 
+ -copyright-
 #-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
@@ -41,7 +42,6 @@
 #include "windows.h"
 #include "dsimple.h"
 #include "debug.h"
-#include "safe_malloc.h"
 
 #include "vroot.h"
 
