@@ -1,4 +1,5 @@
-/* -copyright-
+/* 
+ -copyright-
 #-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
@@ -25,6 +26,7 @@
 #include <X11/Intrinsic.h>
 #include <gtk/gtk.h>
 #include "xdo.h"
+#include "xsnow-constants.h"
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -40,7 +42,9 @@
 #define BITS(n) :n
 #endif
 
-
+// uncomment if you want to use (deprecated) gdk_pixbuf_new_from_xpm_data()
+// in stead of xpm2gdk():
+//#define USE_GDK_PIXBUF_NEW_FROM_XPM_DATA
 
 // timers
 
@@ -52,7 +56,7 @@
 #define time_desktop_type         2.0    // time between showing desktop type
 #define time_display_dimensions   0.5    // time between check of screen dimensions
 #define time_displaychanged       1.00   // time between checks if display has changed
-#define time_emeteor              0.40   // time between meteors erasures
+#define time_emeteor              0.60   // time between meteors erasures
 #define time_event                0.50   // time between checking events
 #define time_flakecount           1.00   // time between updates of show flakecount
 #define time_fuse                 1.00   // time between testing on too much flakes
@@ -71,6 +75,7 @@
 #define time_star                 0.50   // time between drawing stars
 #define time_switchflakes         0.2    // time between checks if flakes should be switched beteen default and vintage
 #define time_testing              2.10   // time between testing code
+#define time_writeflags           0.20   // time between checks if flags should be written
 #define time_ui_check             0.25   // time between checking values from ui
 #define time_umoon                0.04   // time between update position of moon
 #define time_usanta               0.04   // time between update of santa position
@@ -86,6 +91,9 @@
 
 #define ALPHA (0.01*(100 - Flags.Transparency))
 #define XPM_TYPE const char
+
+#define DOCAPELLA                  1  // to convert fallensnow into flakes or not when moving window
+
 /* ------------------------------------------------------------------ */
 
 typedef struct _WinInfo
@@ -171,6 +179,7 @@ typedef struct _SnowMap {
    unsigned int height  BITS(16);
 } SnowMap;
 
+
 extern struct _global
 {
    SnowMap        *fluffpix;
@@ -208,21 +217,22 @@ extern struct _global
    int             SnowWinWidth;
    int             SnowWinHeight;
    int             WindowOffsetX;    // when using the root window for drawing, we need
-   //                                   these offsets to correct for the position of the
-   //                                   windows.
+				     //                                   these offsets to correct for the position of the
+				     //                                   windows.
    int             WindowOffsetY;
    int             SnowWinDepth;
    char           *DesktopSession;
    int             IsCompiz;
    int             IsWayland;
    long            CWorkSpace;  // long? Yes, in compiz we take the placement of the desktop
-   //                                     which can easily be > 16 bits
+				//                                     which can easily be > 16 bits
    long            VisWorkSpaces[MAXVISWORKSPACES];  // these workspaces are visible. In bspwm (and possibly other tiling
-   //                                 widowmanagers) when xsnow is running full-screen, the different
-   //                                 xinerama screens each cover another workspace.
+						     //                                 widowmanagers) when xsnow is running full-screen, the different
+						     //                                 xinerama screens each cover another workspace.
    int             NVisWorkSpaces;  // number of VisWorkSpaces
    long            ChosenWorkSpace; // workspace that is chosen as workspace to snow in
    Window          Rootwindow;
+   GtkBuilder     *builder;
    int             Xroot;
    int             Yroot;
    unsigned int    Wroot;
@@ -268,6 +278,11 @@ extern struct _global
    char            Message[256];
 
    char           *Language;
+
+   int            DoCapella;  // if true, Marc Capella's method is used to
+			      // deal with fallensnow on resized or moved windows:
+			      // fallensnow is turned into flakes.
+   volatile int time_to_write_flags;
 } global;
 
 extern int set_sticky(int s);
